@@ -6,3 +6,6 @@ from .distributions_poisson import PoissonPD as Ppd
 from .distributions_poisson import PoissonCD as Pcd
 from .distributions_poisson import InvPoissonCD as InvP
 
+from .distributions_normal import NormalPD as Npd
+from .distributions_normal import NormalCD as Ncd
+from .distributions_normal import InvNormalCD as InvN
